icsemantic.catalog.criteria

Package platecom :: Package ontocatalog :: Package criteria |
[hide private]
[frames] | no frames]

# Source Code for Package icsemantic.catalog.criteria

    1  """In this module defines three criteria content types for ATTopic to
    2  match the catalog indexes defined in the 'indexes' module.
    3  """
    4
    5  import platecom.ontocatalog.criteria.related
    6  import platecom.ontocatalog.criteria.synonym
    7  import platecom.ontocatalog.criteria.translation
    8